#loading-overlay {
    background-color: rgba(0, 0, 0, 0.5);
    position: fixed;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    z-index: 1000;
    display: flex;
    justify-content: center;
    align-items: center;
}

#loading-label {
    background-color: white;
    padding: 10px 20px;
    border-radius: 5px;
    color: black;
}